scxpand.linear.sklearn\_utils
=============================

.. automodule:: scxpand.linear.sklearn_utils

   
   .. rubric:: Functions

   .. autosummary::
   
      load_sklearn_model
      run_linear_inference
   